A program to measure the temperature using the Max6675 board. The temperature is shown on 8x8 Max7219 matrix display and it is saved on SD as well.

Dependencies:   MAX7219 SDFileSystem mbed

Fork of MAXREFDES99_demo by Maxim Integrated

The program measures the temperature using the Max6675 board designed for Arduino. The temperature is shown on Max7219 8x8 matrix display (designed for Arduino as well) as text marque from right to left. The fonf size is 5x7 so the last row is used to show some info:

- All leds off: Normal temperature measuring - Leds shifting: Saving on SD card - Leds blinking: SD card missing or damaged

The Blue "user button" is used to save measured temperature on SD card. First click start saving, the second stop the process. Together the temperature is saved also the time. The time is reset when the process start. Connecting the USB to PC it's possible to see instant temperature and all saved data on SD.

Revision:
3:41bdbc9b3cec
Parent:
1:06c0a61ca171
Child:
6:00aabe967e51
--- a/maxrefdes99.h	Thu Mar 24 23:35:56 2016 +0000
+++ b/maxrefdes99.h	Mon Apr 11 16:19:13 2016 +0000
@@ -3,13 +3,13 @@
 *
 * @author Justin Jordan
 *
-* @version 0.0
+* @version 0.1
 *
 * Started: 08JAN16
 *
-* Updated: 
+* Updated: 11APR16,Pradip Vatharkar 
 *
 * @brief Header file for maxrefdes99 demo
 ***********************************************************************
 * Copyright (C) 2016 Maxim Integrated Products, Inc., All Rights Reserved.
 *
@@ -227,6 +227,117 @@
 **************************************************************/
 void endless_scroll_display(Max7219 *display, uint32_t scroll_right);
 
+/**********************************************************//**
+* @brief gets 16x16 character bitmap fom memory
+* 
+* @details 
+*
+* On Entry:
+*     @param[in] c - character to get bitmap for
+*     @param[in] char_buff - pointer to buffer to store bitmap 
+*                            Buffer should be 32 bytes
+*
+* On Exit:
+*    @return none
+**************************************************************/
+void get_16x16_character(char c, uint8_t *char_buff);
+
+
+/**********************************************************//**
+* @brief prints character to MAXREFDES99 16x16 LED display
+* 
+* @details 
+*
+* On Entry:
+*     @param[in] p_display - pointer to Max7219 object
+      @param[in] position -  for single char print this value is zero,
+                 for string case it is multiple of 32 bytes as each char data is 32 bytes, 
+*     @param[in] c - char to print
+*
+* On Exit:
+*    @return none
+**************************************************************/
+void print_char_16x16(Max7219 *p_display, uint16_t position, char c);
+
+
+/**********************************************************//**
+* @brief prints given string to MAXREFDES99 16x16 LED display
+* 
+* @details 
+*
+* On Entry:
+*     @param[in] p_display - pointer to Max7219 object
+*     @param[in] s - pointer to string to print
+*
+* On Exit:
+*    @return none
+**************************************************************/
+void print_string_16x16(Max7219 *p_display, char *s);
+
+
+/**********************************************************//**
+* @brief shifts display right 'count' positions with given
+*        delay between shifts 
+* 
+* @details 
+*
+* On Entry:
+*     @param[in] p_display - pointer to Max7219 object
+*     @param[in] count - number of positions to shift
+*     @param[in] delay - delay between shifts in milliseconds
+*
+* On Exit:
+*    @return none
+**************************************************************/
+void shift_display_right_16x16(Max7219 *p_display, uint8_t count, uint8_t delay);
+
+
+/**********************************************************//**
+* @brief shifts display left 'count' positions with given
+*        delay between shifts
+* 
+* @details 
+*
+* On Entry:
+*     @param[in] p_display - pointer to Max7219 object
+*     @param[in] count - number of positions to shift
+*     @param[in] delay - delay between shifts in milliseconds
+*
+* On Exit:
+*    @return none
+**************************************************************/
+void shift_display_left_16x16(Max7219 *p_display, uint8_t count, uint8_t delay);
+
+/**********************************************************//**
+* @brief demo loop for MAXREFDES99 with 16x16 font display
+* 
+* @details 
+*
+* On Entry:
+*     @param[in] p_display - pointer to Max7219 object
+*     @param[in] display_config - structure holding configuration data
+*     @param[in] endless_loop - if true run demo in endless loop
+*
+* On Exit:
+*    @return none
+**************************************************************/
+void demo_16x16(Max7219 *display, max7219_configuration_t display_config, bool endless_loop);
+
+
+/**********************************************************//**
+* @brief shift display in given direction forever
+* 
+* @details 
+*
+* On Entry:
+*     @param[in] p_display - pointer to Max7219 object
+*     @param[in] scroll_right - if true shift right, else shift left
+*
+* On Exit:
+*    @return none
+**************************************************************/
+void endless_scroll_display_16x16(Max7219 *display, uint32_t scroll_right);
+
 
 /**********************************************************//**
 * @brief print demo menu
@@ -3,13 +3,13 @@
 *
-* @brief Header file for maxrefdes99 demo
+* @brief Header file for maxrefdes99 demo with 5x7 & 16x16 fonts  
 ***********************************************************************
 * Copyright (C) 2016 Maxim Integrated Products, Inc., All Rights Reserved.